@@ -23,10 +23,13 @@ import javax.enterprise.event.Event;
 import javax.enterprise.event.Observes;
 import javax.inject.Inject;
 
+import org.appformer.client.context.EditorContextProvider;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.kie.workbench.common.dmn.api.qualifiers.DMNEditor;
 import org.kie.workbench.common.dmn.client.docks.navigator.DecisionNavigatorDock;
 import org.kie.workbench.common.dmn.client.editors.expressions.ExpressionEditorView;
+import org.kie.workbench.common.dmn.client.editors.included.IncludedModelsPage;
+import org.kie.workbench.common.dmn.client.editors.included.imports.IncludedModelsPageStateProviderImpl;
 import org.kie.workbench.common.dmn.client.editors.search.DMNEditorSearchIndex;
 import org.kie.workbench.common.dmn.client.editors.search.DMNSearchableElement;
 import org.kie.workbench.common.dmn.client.editors.types.DataTypePageTabActiveEvent;
@@ -40,6 +43,7 @@ import org.kie.workbench.common.dmn.webapp.common.client.docks.preview.PreviewDi
 import org.kie.workbench.common.dmn.webapp.kogito.common.client.editor.AbstractDMNDiagramEditor;
 import org.kie.workbench.common.dmn.webapp.kogito.common.client.editor.DMNEditorMenuSessionItems;
 import org.kie.workbench.common.dmn.webapp.kogito.common.client.editor.DMNProjectToolbarStateHandler;
+import org.kie.workbench.common.dmn.webapp.kogito.common.client.tour.GuidedTourBridgeInitializer;
 import org.kie.workbench.common.kogito.client.editor.MultiPageEditorContainerView;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionEditorPresenter;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionViewerPresenter;
@@ -126,7 +130,11 @@ public class DMNDiagramEditor extends AbstractDMNDiagramEditor {
                             final DMNVFSService vfsService,
                             final Promises promises,
                             final MonacoFEELInitializer feelInitializer,
-                            final CanvasFileExport canvasFileExport) {
+                            final CanvasFileExport canvasFileExport,
+                            final IncludedModelsPage includedModelsPage,
+                            final IncludedModelsPageStateProviderImpl importsPageProvider,
+                            final EditorContextProvider contextProvider,
+                            final GuidedTourBridgeInitializer guidedTourBridgeInitializer) {
         super(view,
               fileMenuBuilder,
               placeManager,
@@ -156,7 +164,11 @@ public class DMNDiagramEditor extends AbstractDMNDiagramEditor {
               diagramServices,
               feelInitializer,
               canvasFileExport,
-              promises);
+              promises,
+              includedModelsPage,
+              importsPageProvider,
+              contextProvider,
+              guidedTourBridgeInitializer);
         this.notificationEvent = notificationEvent;
         this.vfsService = vfsService;
     }
@@ -207,6 +219,7 @@ public class DMNDiagramEditor extends AbstractDMNDiagramEditor {
             expressionEditor.setToolbarStateHandler(new DMNProjectToolbarStateHandler(getMenuSessionItems()));
             decisionNavigatorDock.setupCanvasHandler(c);
             dataTypesPage.reload();
+            includedModelsPage.setup(importsPageProvider.withDiagram(c.getDiagram()));
         });
     }
 
