@@ -272,6 +272,15 @@ public class LibraryConstants {
     @TranslationKey(defaultValue = "")
     public static final String Version = "Version";
 
+    @TranslationKey(defaultValue = "")
+    public static final String BasedOnTemplate = "BasedOnTemplate";
+
+    @TranslationKey(defaultValue = "")
+    public static final String NoTemplatesAvailable = "NoTemplatesAvailable";
+
+    @TranslationKey(defaultValue = "")
+    public static final String ArchetypeListUpdatedMessage = "ArchetypeListUpdatedMessage";
+
     @TranslationKey(defaultValue = "")
     public static final String ImportProject = "ImportProject";
 
@@ -766,4 +775,16 @@ public class LibraryConstants {
 
     @TranslationKey(defaultValue = "")
     public static final String ErrorCreatingPoject = "ErrorCreatingProject";
+
+    @TranslationKey(defaultValue = "")
+    public static final String SpacePermissionsChanged = "SpacePermissionsChanged";
+
+    @TranslationKey(defaultValue = "")
+    public static final String SpaceDescriptionChanged = "SpaceDescriptionChanged";
+
+    @TranslationKey(defaultValue = "")
+    public static final String SquashAndMerge = "SquashAndMerge";
+
+    @TranslationKey(defaultValue = "")
+    public static final String InvalidCommitMessage = "InvalidCommitMessage";
 }
