@@ -16,6 +16,9 @@
 
 package org.kie.workbench.common.workbench.client.admin;
 
+import java.util.ArrayList;
+import java.util.List;
+
 import com.google.gwtmockito.GwtMockitoTestRunner;
 import org.guvnor.common.services.shared.preferences.GuvnorPreferenceScopes;
 import org.jboss.errai.security.shared.api.identity.User;
@@ -23,13 +26,19 @@ import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.kie.workbench.common.profile.api.preferences.ProfileService;
 import org.kie.workbench.common.workbench.client.authz.WorkbenchFeatures;
 import org.kie.workbench.common.workbench.client.resources.i18n.DefaultWorkbenchConstants;
 import org.mockito.InjectMocks;
 import org.mockito.Mock;
 import org.mockito.stubbing.Answer;
+import org.uberfire.experimental.client.service.ClientExperimentalFeaturesRegistryService;
+import org.uberfire.experimental.service.registry.ExperimentalFeature;
+import org.uberfire.experimental.service.registry.ExperimentalFeaturesRegistry;
 import org.uberfire.ext.preferences.client.admin.page.AdminPage;
 import org.uberfire.ext.preferences.client.admin.page.AdminPageOptions;
+import org.uberfire.mocks.CallerMock;
+import org.uberfire.mvp.Command;
 import org.uberfire.preferences.shared.PreferenceScope;
 import org.uberfire.preferences.shared.PreferenceScopeFactory;
 import org.uberfire.rpc.SessionInfo;
@@ -37,7 +46,6 @@ import org.uberfire.security.ResourceRef;
 import org.uberfire.security.authz.AuthorizationManager;
 
 import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.anyString;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.RETURNS_DEFAULTS;
 import static org.mockito.Mockito.doReturn;
@@ -45,13 +53,20 @@ import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(GwtMockitoTestRunner.class)
 public class DefaultAdminPageHelperTest {
 
     private static String LIBRARY_PREFERENCES = "LibraryPreferences";
+    private static String PROFILE_PREFERENCES = "ProfilePreferences";
     private static String ARTIFACT_REPOSITORY_PREFERENCES = "ArtifactRepositoryPreference";
     private static String STUNNER_PREFERENCES = "StunnerPreferences";
+    private static String EXPERIMENTAL_SETTINGS = "ExperimentalSettings";
+    private static String MANAGE_PREFERENCES = "ManagePreferences";
+    private static String SERTIVCE_TASKS_ADMIN = "ServiceTasksAdministration";
+    private static String DATA_TRANSFER = "DataTransfer";
+    private static String ARCHETYPES = "Archetypes";
 
     @Mock
     private AdminPage adminPage;
@@ -68,15 +83,24 @@ public class DefaultAdminPageHelperTest {
     @Mock
     private PreferenceScopeFactory scopeFactory;
 
+    @Mock
+    private ClientExperimentalFeaturesRegistryService experimentalFeaturesRegistryService;
+
     @InjectMocks
     private DefaultAdminPageHelper defaultAdminPageHelper;
 
     @Mock
     private PreferenceScope globalScope;
 
+    @Mock
+    ProfileService profileService;
+
+    CallerMock<ProfileService> profileServiceCaller;
+
     @Before
     public void setup() {
         mockConstants();
+        mockProfileService();
     }
 
     @Test
@@ -229,6 +253,8 @@ public class DefaultAdminPageHelperTest {
         defaultAdminPageHelper.setup();
         verifyLibraryPreferencesWasAddedInGlobalScope();
         verifyArtifactRepositoryPreferencesWasAddedInGlobalScope();
+        verifyManagePreferencesWasAddedInGlobalScope();
+        verifyServiceTasksAdminWasAdded();
     }
 
     @Test
@@ -243,10 +269,13 @@ public class DefaultAdminPageHelperTest {
                                      true);
         verifyLibraryPreferencesWasAddedInGlobalScope();
         verifyArtifactRepositoryPreferencesWasAddedInGlobalScope();
+        verifyManagePreferencesWasAddedInGlobalScope();
+        verifyServiceTasksAdminWasAdded();
     }
 
     @Test
     public void preferencesShouldNotBeAddedWhenUserHasPermissionAndDisabledTest() {
+        doReturn(globalScope).when(scopeFactory).createScope(GuvnorPreferenceScopes.GLOBAL);
         doReturn(true).when(authorizationManager).authorize(eq(WorkbenchFeatures.EDIT_GLOBAL_PREFERENCES),
                                                             any());
 
@@ -255,6 +284,8 @@ public class DefaultAdminPageHelperTest {
                                      false);
         verifyLibraryPreferencesWasNotAdded();
         verifyArtifactRepositoryPreferencesWasNotAdded();
+        verifyManagePreferencesWasAddedInGlobalScope();
+        verifyServiceTasksAdminWasAdded();
     }
 
     @Test
@@ -265,6 +296,8 @@ public class DefaultAdminPageHelperTest {
         defaultAdminPageHelper.setup();
         verifyLibraryPreferencesWasNotAdded();
         verifyArtifactRepositoryPreferencesWasNotAdded();
+        verifyManagePreferencesWasNotAdded();
+        verifyServiceTasksAdminWasNotAdded();
     }
 
     @Test
@@ -278,6 +311,47 @@ public class DefaultAdminPageHelperTest {
 
         verifyLibraryPreferencesWasNotAdded();
         verifyArtifactRepositoryPreferencesWasNotAdded();
+        verifyManagePreferencesWasNotAdded();
+        verifyServiceTasksAdminWasNotAdded();
+    }
+
+    @Test
+    public void sshKeysAdded() {
+        defaultAdminPageHelper.setup();
+
+        final String title = defaultAdminPageHelper.constants.SSHKeys();
+
+        verify(adminPage).addTool(eq("root"),
+                                  eq(title),
+                                  any(),
+                                  eq("general"),
+                                  any(Command.class));
+    }
+
+    @Test
+    public void profilePreferencesWasAddedWithPermissionTest() {
+        doReturn(true).when(authorizationManager).authorize(eq(WorkbenchFeatures.EDIT_PROFILE_PREFERENCES),
+                any());
+        defaultAdminPageHelper.setup();
+        verifyProfilePreferenceAdded(true);
+    }
+
+    @Test
+    public void profilePreferencesWasNotAddedTest() {
+        doReturn(false).when(authorizationManager).authorize(eq(WorkbenchFeatures.EDIT_PROFILE_PREFERENCES),
+                any());
+
+        defaultAdminPageHelper.setup();
+        verifyProfilePreferenceAdded(false);
+    }
+
+    @Test
+    public void profilePreferencesWasNotAddedWithPermissionWithForceTest() {
+        when(profileService.isForce()).thenReturn(true);
+        doReturn(true).when(authorizationManager).authorize(eq(WorkbenchFeatures.EDIT_PROFILE_PREFERENCES),
+                any());
+        defaultAdminPageHelper.setup();
+        verifyProfilePreferenceAdded(false);
     }
 
     @Test
@@ -300,13 +374,116 @@ public class DefaultAdminPageHelperTest {
         verifyStunnerPreferencesWasAdded(0);
     }
 
+    @Test
+    public void experimentalFeaturesAddedTest() {
+        verifyExperimentalFeatureAdded(true, true);
+    }
+
+    @Test
+    public void experimentalFeaturesAddedTestWithoutFeatures() {
+        verifyExperimentalFeatureAdded(true, false);
+    }
+
+    @Test
+    public void experimentalFeaturesWasNotAddedTest() {
+        verifyExperimentalFeatureAdded(false, false);
+    }
+
+    @Test
+    public void dataTransferAddedTest() {
+        doReturn(true).when(authorizationManager).authorize(eq(WorkbenchFeatures.ACCESS_DATA_TRANSFER), any());
+        defaultAdminPageHelper.setup();
+        verifyDataTransferAdded(true);
+    }
+
+    @Test
+    public void dataTransferNotAddedTest() {
+        doReturn(false).when(authorizationManager).authorize(eq(WorkbenchFeatures.ACCESS_DATA_TRANSFER), any());
+        defaultAdminPageHelper.setup();
+        verifyDataTransferAdded(false);
+    }
+
+    private void verifyDataTransferAdded(boolean expected) {
+        verify(adminPage, expected ? times(1) : never())
+            .addTool(eq("root"), eq(DATA_TRANSFER), any(), eq("services"), any(Command.class));
+    }
+
+    @Test
+    public void archetypesAllowedTest() {
+        doReturn(true).when(authorizationManager).authorize(any(ResourceRef.class),
+                                                            any(User.class));
+        defaultAdminPageHelper.setup();
+        verifyArchetypesAdded(true);
+    }
+
+    @Test
+    public void archetypesNotAllowedTest() {
+        doReturn(false).when(authorizationManager).authorize(any(ResourceRef.class),
+                                                             any(User.class));
+        defaultAdminPageHelper.setup();
+        verifyArchetypesAdded(false);
+    }
+
+    @Test
+    public void archetypesCannotBeAddedWithoutLibraryTest() {
+        defaultAdminPageHelper.setup(false, true, true);
+        verifyArchetypesAdded(false);
+    }
+
+    private void verifyArchetypesAdded(final boolean expected) {
+        verify(adminPage, expected ? times(1) : never())
+                .addTool(eq("root"),
+                         eq(ARCHETYPES),
+                         any(),
+                         eq("advanced"),
+                         any(Command.class));
+    }
+
+    private void verifyExperimentalFeatureAdded(final boolean addExperimental, final boolean addFeatures) {
+        doReturn(true).when(authorizationManager).authorize(any(ResourceRef.class), any(User.class));
+
+        List<ExperimentalFeature> definitions = new ArrayList<>();
+        ExperimentalFeaturesRegistry registry = mock(ExperimentalFeaturesRegistry.class);
+
+        when(registry.getAllFeatures()).thenReturn(definitions);
+
+        when(experimentalFeaturesRegistryService.getFeaturesRegistry()).thenReturn(registry);
+
+        if (addFeatures) {
+            definitions.add(mock(ExperimentalFeature.class));
+            definitions.add(mock(ExperimentalFeature.class));
+        }
+
+        when(experimentalFeaturesRegistryService.isExperimentalEnabled()).thenReturn(addExperimental);
+
+        defaultAdminPageHelper.setup();
+
+        boolean shouldAppear = addExperimental && addFeatures;
+
+        verify(adminPage, shouldAppear ? times(1) : never()).addTool(eq("root"),
+                                                                        eq(EXPERIMENTAL_SETTINGS),
+                                                                        any(),
+                                                                        eq("advanced"),
+                                                                        any(Command.class));
+    }
+
+    private void verifyProfilePreferenceAdded(boolean authorized) {
+        verify(adminPage, authorized ? times(1) : never()).addPreference(eq("root"),
+                                        eq(PROFILE_PREFERENCES),
+                                        any(),
+                                        any(),
+                                        eq("advanced"),
+                                        any(PreferenceScope.class),
+                                        eq(AdminPageOptions.WITH_BREADCRUMBS));
+    }
+
     private void verifyLibraryPreferencesWasAddedInGlobalScope() {
         verify(adminPage,
                times(1)).addPreference(eq("root"),
                                        eq(LIBRARY_PREFERENCES),
-                                       anyString(),
-                                       anyString(),
-                                       anyString(),
+                                       any(),
+                                       any(),
+                                       any(),
                                        eq(globalScope),
                                        eq(AdminPageOptions.WITH_BREADCRUMBS));
     }
@@ -315,9 +492,9 @@ public class DefaultAdminPageHelperTest {
         verify(adminPage,
                never()).addPreference(eq("root"),
                                       eq(LIBRARY_PREFERENCES),
-                                      anyString(),
-                                      anyString(),
-                                      anyString(),
+                                      any(),
+                                      any(),
+                                      any(),
                                       any(PreferenceScope.class),
                                       eq(AdminPageOptions.WITH_BREADCRUMBS));
     }
@@ -326,20 +503,42 @@ public class DefaultAdminPageHelperTest {
         verify(adminPage,
                times(1)).addPreference(eq("root"),
                                        eq(ARTIFACT_REPOSITORY_PREFERENCES),
-                                       anyString(),
-                                       anyString(),
-                                       anyString(),
+                                       any(),
+                                       any(),
+                                       any(),
                                        eq(globalScope),
                                        eq(AdminPageOptions.WITH_BREADCRUMBS));
     }
 
+    private void verifyManagePreferencesWasAddedInGlobalScope() {
+        verify(adminPage,
+               times(1)).addPreference(eq("root"),
+                                       eq(MANAGE_PREFERENCES),
+                                       any(),
+                                       any(),
+                                       any(),
+                                       eq(globalScope),
+                                       eq(AdminPageOptions.WITH_BREADCRUMBS));
+    }
+
+    private void verifyManagePreferencesWasNotAdded() {
+        verify(adminPage,
+               never()).addPreference(eq("root"),
+                                      eq(MANAGE_PREFERENCES),
+                                      any(),
+                                      any(),
+                                      any(),
+                                      eq(globalScope),
+                                      eq(AdminPageOptions.WITH_BREADCRUMBS));
+    }
+
     private void verifyArtifactRepositoryPreferencesWasNotAdded() {
         verify(adminPage,
                never()).addPreference(eq("root"),
                                       eq(ARTIFACT_REPOSITORY_PREFERENCES),
-                                      anyString(),
-                                      anyString(),
-                                      anyString(),
+                                      any(),
+                                      any(),
+                                      any(),
                                       any(PreferenceScope.class),
                                       eq(AdminPageOptions.WITH_BREADCRUMBS));
     }
@@ -347,12 +546,31 @@ public class DefaultAdminPageHelperTest {
     private void verifyStunnerPreferencesWasAdded(int timesAdded) {
         verify(adminPage,
                times(timesAdded)).addPreference(eq("root"),
-                                           eq(STUNNER_PREFERENCES),
-                                           anyString(),
-                                           anyString(),
-                                           anyString(),
-                                           any(PreferenceScope.class),
-                                           eq(AdminPageOptions.WITH_BREADCRUMBS));
+                                                eq(STUNNER_PREFERENCES),
+                                                any(),
+                                                any(),
+                                                any(),
+                                                any(PreferenceScope.class),
+                                                eq(AdminPageOptions.WITH_BREADCRUMBS));
+    }
+
+
+    private void verifyServiceTasksAdminWasAdded() {
+        verify(adminPage,
+               times(1)).addTool(eq("root"),
+                                                eq(SERTIVCE_TASKS_ADMIN),
+                                                any(),
+                                                eq("services"),
+                                                any());
+    }
+
+    private void verifyServiceTasksAdminWasNotAdded() {
+        verify(adminPage,
+               never()).addTool(eq("root"),
+                                                eq(SERTIVCE_TASKS_ADMIN),
+                                                any(),
+                                                eq("services"),
+                                                any());
     }
 
     private void mockConstants() {
@@ -365,4 +583,8 @@ public class DefaultAdminPageHelperTest {
                                                     }
                                                 });
     }
+
+    private void mockProfileService() {
+        defaultAdminPageHelper.profileService = new CallerMock<ProfileService>(profileService);
+    }
 }
