@@ -20,23 +20,33 @@ import java.util.Map;
 
 import com.google.gwt.dev.util.collect.HashMap;
 import com.google.gwtmockito.GwtMockitoTestRunner;
-import junit.framework.Assert;
 import org.guvnor.common.services.shared.config.AppConfigService;
+import org.jboss.errai.bus.client.api.messaging.Message;
+import org.jboss.errai.bus.client.framework.AbstractRpcProxy;
+import org.jboss.errai.common.client.api.ErrorCallback;
+import org.jboss.errai.marshalling.client.MarshallingSessionProviderFactory;
+import org.jboss.errai.marshalling.client.protocols.MarshallingSessionProvider;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.services.shared.preferences.ApplicationPreferences;
+import org.kie.workbench.common.workbench.client.error.DefaultWorkbenchErrorCallback;
 import org.mockito.Mock;
-import org.uberfire.client.callbacks.Callback;
 import org.uberfire.client.mvp.ActivityBeansCache;
 import org.uberfire.mocks.CallerMock;
 
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.mockito.Mockito.doNothing;
+import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.verify;
 
 @RunWith(GwtMockitoTestRunner.class)
 public class DefaultWorkbenchEntryPointTest {
 
     private AppConfigService appConfigService;
+
     private CallerMock<AppConfigService> appConfigServiceCallerMock;
 
     private ActivityBeansCache activityBeansCache;
@@ -44,10 +54,10 @@ public class DefaultWorkbenchEntryPointTest {
     private DefaultWorkbenchEntryPoint entryPoint;
 
     @Mock
-    private Callback<String> callback1;
+    private GenericErrorPopup genericErrorPopup;
 
     @Mock
-    private Callback<String> callback2;
+    private DefaultWorkbenchErrorCallback defaultWorkbenchErrorCallback;
 
     @Before
     public void setup() {
@@ -55,11 +65,13 @@ public class DefaultWorkbenchEntryPointTest {
         mockActivityBeansCache();
 
         entryPoint = spy(new DefaultWorkbenchEntryPoint(appConfigServiceCallerMock,
-                                                        activityBeansCache) {
+                                                        activityBeansCache,
+                                                        defaultWorkbenchErrorCallback) {
             @Override
             protected void setupMenu() {
             }
         });
+        entryPoint.setGenericErrorPopup(genericErrorPopup);
         doNothing().when(entryPoint).hideLoadingPopup();
     }
 
@@ -78,10 +90,22 @@ public class DefaultWorkbenchEntryPointTest {
         verify(entryPoint).setupMenu();
         verify(entryPoint).setupAdminPage();
 
-        Assert.assertEquals("value",
-                            ApplicationPreferences.getStringPref("key"));
+        assertEquals("value", ApplicationPreferences.getStringPref("key"));
     }
 
+    @Test
+    public void testSetupRpcDefaultErrorCallback() {
+        MarshallingSessionProviderFactory.setMarshallingSessionProvider(mock(MarshallingSessionProvider.class));
+        AbstractRpcProxy.DEFAULT_RPC_ERROR_CALLBACK = mock(ErrorCallback.class);
+        
+        entryPoint.setupRpcDefaultErrorCallback();
+
+        AbstractRpcProxy.DEFAULT_RPC_ERROR_CALLBACK.error(mock(Message.class), new RuntimeException());
+        
+        verify(genericErrorPopup).setup("{}");
+    }
+
+
     private void mockActivityBeansCache() {
         activityBeansCache = mock(ActivityBeansCache.class);
     }
@@ -89,8 +113,7 @@ public class DefaultWorkbenchEntryPointTest {
     private void mockAppConfigService() {
         appConfigService = mock(AppConfigService.class);
         Map<String, String> preferencesMap = new HashMap<>();
-        preferencesMap.put("key",
-                           "value");
+        preferencesMap.put("key", "value");
         doReturn(preferencesMap).when(appConfigService).loadPreferences();
         appConfigServiceCallerMock = new CallerMock<>(appConfigService);
     }
