@@ -16,24 +16,51 @@
 
 package org.kie.workbench.common.workbench.client.menu;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+import static org.kie.workbench.common.services.shared.resources.PerspectiveIds.CONTENT_MANAGEMENT;
+import static org.kie.workbench.common.services.shared.resources.PerspectiveIds.EXECUTION_ERRORS;
+import static org.kie.workbench.common.services.shared.resources.PerspectiveIds.HOME;
+import static org.kie.workbench.common.services.shared.resources.PerspectiveIds.JOBS;
+import static org.kie.workbench.common.services.shared.resources.PerspectiveIds.LIBRARY;
+import static org.kie.workbench.common.services.shared.resources.PerspectiveIds.PROCESS_DASHBOARD;
+import static org.kie.workbench.common.services.shared.resources.PerspectiveIds.PROCESS_DEFINITIONS;
+import static org.kie.workbench.common.services.shared.resources.PerspectiveIds.PROCESS_INSTANCES;
+import static org.kie.workbench.common.services.shared.resources.PerspectiveIds.PROVISIONING;
+import static org.kie.workbench.common.services.shared.resources.PerspectiveIds.SERVER_MANAGEMENT;
+import static org.kie.workbench.common.services.shared.resources.PerspectiveIds.TASKS;
+import static org.kie.workbench.common.services.shared.resources.PerspectiveIds.TASK_DASHBOARD;
+import static org.mockito.Matchers.any;
+import static org.mockito.Matchers.anyString;
+import static org.mockito.Matchers.eq;
+import static org.mockito.Mockito.RETURNS_DEFAULTS;
+import static org.mockito.Mockito.doAnswer;
+import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.uberfire.mocks.ParametrizedCommandMock.executeParametrizedCommandWith;
+
 import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
+import java.util.UUID;
+import java.util.function.Consumer;
 
-import com.google.gwtmockito.GwtMockitoTestRunner;
 import org.dashbuilder.navigation.NavTree;
 import org.dashbuilder.navigation.impl.NavTreeBuilder;
-import org.jboss.errai.common.client.api.Caller;
-import org.jboss.errai.common.client.api.RemoteCallback;
 import org.jboss.errai.ioc.client.container.SyncBeanDef;
 import org.jboss.errai.ioc.client.container.SyncBeanManager;
 import org.jboss.errai.security.shared.api.Group;
 import org.jboss.errai.security.shared.api.Role;
 import org.jboss.errai.security.shared.api.identity.User;
-import org.jboss.errai.security.shared.service.AuthenticationService;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.kie.workbench.common.profile.api.preferences.ProfilePreferences;
+import org.kie.workbench.common.profile.api.preferences.Profile;
 import org.kie.workbench.common.widgets.client.menu.AboutCommand;
 import org.kie.workbench.common.workbench.client.admin.DefaultAdminPageHelper;
 import org.kie.workbench.common.workbench.client.resources.i18n.DefaultWorkbenchConstants;
@@ -41,20 +68,22 @@ import org.mockito.ArgumentCaptor;
 import org.mockito.InjectMocks;
 import org.mockito.Mock;
 import org.mockito.Spy;
-import org.mockito.invocation.InvocationOnMock;
 import org.mockito.stubbing.Answer;
 import org.uberfire.client.mvp.ActivityManager;
 import org.uberfire.client.mvp.PerspectiveManager;
+import org.uberfire.client.mvp.PlaceManager;
 import org.uberfire.client.views.pfly.menu.UserMenu;
 import org.uberfire.client.workbench.widgets.menu.UtilityMenuBar;
 import org.uberfire.client.workbench.widgets.menu.megamenu.WorkbenchMegaMenuPresenter;
 import org.uberfire.mvp.Command;
+import org.uberfire.mvp.ParameterizedCommand;
+import org.uberfire.mvp.PlaceRequest;
+import org.uberfire.mvp.impl.DefaultPlaceRequest;
 import org.uberfire.workbench.model.menu.MenuGroup;
 import org.uberfire.workbench.model.menu.MenuItem;
 import org.uberfire.workbench.model.menu.Menus;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import com.google.gwtmockito.GwtMockitoTestRunner;
 
 @RunWith(GwtMockitoTestRunner.class)
 public class DefaultWorkbenchFeaturesMenusHelperTest {
@@ -86,9 +115,15 @@ public class DefaultWorkbenchFeaturesMenusHelperTest {
     @Mock
     protected AboutCommand aboutCommand;
 
+    @Mock
+    protected PlaceManager placeManager;
+
     @Spy
     @InjectMocks
     private DefaultWorkbenchFeaturesMenusHelper menusHelper;
+    
+    @Mock
+    protected ProfilePreferences profilePreferences;
 
     @Before
     public void setup() {
@@ -97,13 +132,14 @@ public class DefaultWorkbenchFeaturesMenusHelperTest {
         mockRoles();
         mockGroups();
         mockIocManager();
+        executeParametrizedCommandWith(0, new ProfilePreferences(Profile.FULL))
+                .when(profilePreferences).load(any(ParameterizedCommand.class), 
+                                                any(ParameterizedCommand.class)); 
     }
 
     @Test
-    public void getHomeViewsWithoutSocial() {
-        final boolean socialEnabled = false;
-
-        List<? extends MenuItem> homeMenuItems = menusHelper.getHomeViews(socialEnabled);
+    public void getHomeViews() {
+        List<? extends MenuItem> homeMenuItems = menusHelper.getHomeViews();
 
         assertEquals(2,
                      homeMenuItems.size());
@@ -113,24 +149,6 @@ public class DefaultWorkbenchFeaturesMenusHelperTest {
                      homeMenuItems.get(1).getCaption());
     }
 
-    @Test
-    public void getHomeViewsWithSocial() {
-        final boolean socialEnabled = true;
-
-        List<? extends MenuItem> homeMenuItems = menusHelper.getHomeViews(socialEnabled);
-
-        assertEquals(4,
-                     homeMenuItems.size());
-        assertEquals(menusHelper.constants.HomePage(),
-                     homeMenuItems.get(0).getCaption());
-        assertEquals(menusHelper.constants.Admin(),
-                     homeMenuItems.get(1).getCaption());
-        assertEquals(menusHelper.constants.Timeline(),
-                     homeMenuItems.get(2).getCaption());
-        assertEquals(menusHelper.constants.People(),
-                     homeMenuItems.get(3).getCaption());
-    }
-
     @Test
     public void getAuthoringViewsTest() {
         List<? extends MenuItem> authoringMenuItems = menusHelper.getAuthoringViews();
@@ -333,6 +351,9 @@ public class DefaultWorkbenchFeaturesMenusHelperTest {
     @Test
     @SuppressWarnings("unchecked")
     public void logoutCommandRedirectIncludesLocaleTest() throws Throwable {
+        final PlaceRequest currentPerspective = mock(PlaceRequest.class);
+        doReturn(currentPerspective).when(perspectiveManager).getCurrentPerspectivePlaceRequest();
+
         final DefaultWorkbenchFeaturesMenusHelper.LogoutCommand logoutCommand = spy(menusHelper.new LogoutCommand() {
 
             @Override
@@ -366,6 +387,14 @@ public class DefaultWorkbenchFeaturesMenusHelperTest {
         final Command postSaveStateCommand = postSaveStateCommandCaptor.getValue();
         postSaveStateCommand.execute();
 
+        final ArgumentCaptor<Command> doAfterCloseCommandCaptor = ArgumentCaptor.forClass(Command.class);
+
+        verify(placeManager).closePlace(eq(currentPerspective),
+                                        doAfterCloseCommandCaptor.capture());
+
+        final Command doAfterCloseCommand = doAfterCloseCommandCaptor.getValue();
+        doAfterCloseCommand.execute();
+
         verify(logoutCommand).getRedirectURL();
         verify(logoutCommand).doRedirect(redirectURLCaptor.capture());
 
@@ -425,6 +454,23 @@ public class DefaultWorkbenchFeaturesMenusHelperTest {
                      "i2");
     }
 
+    @Test
+    public void testResolvePlaceRequest() {
+        assertTrue(menusHelper.resolvePlaceRequest(HOME) instanceof DefaultPlaceRequest);
+        assertTrue(menusHelper.resolvePlaceRequest(LIBRARY) instanceof DefaultPlaceRequest);
+        assertTrue(menusHelper.resolvePlaceRequest(CONTENT_MANAGEMENT) instanceof DefaultPlaceRequest);
+        assertTrue(menusHelper.resolvePlaceRequest(PROVISIONING) instanceof DefaultPlaceRequest);
+        assertTrue(menusHelper.resolvePlaceRequest(SERVER_MANAGEMENT) instanceof DefaultPlaceRequest);
+        assertTrue(menusHelper.resolvePlaceRequest(CONTENT_MANAGEMENT) instanceof DefaultPlaceRequest);
+        assertTrue(menusHelper.resolvePlaceRequest(PROCESS_DEFINITIONS) instanceof DefaultPlaceRequest);
+        assertTrue(menusHelper.resolvePlaceRequest(PROCESS_INSTANCES) instanceof DefaultPlaceRequest);
+        assertTrue(menusHelper.resolvePlaceRequest(JOBS) instanceof DefaultPlaceRequest);
+        assertTrue(menusHelper.resolvePlaceRequest(EXECUTION_ERRORS) instanceof DefaultPlaceRequest);
+        assertTrue(menusHelper.resolvePlaceRequest(TASKS) instanceof DefaultPlaceRequest);
+        assertTrue(menusHelper.resolvePlaceRequest(PROCESS_DASHBOARD) instanceof DefaultPlaceRequest);
+        assertTrue(menusHelper.resolvePlaceRequest(TASK_DASHBOARD) instanceof DefaultPlaceRequest);
+    }
+
     private void mockGroups() {
         Set<Group> groups = new HashSet<>(2);
         groups.add(() -> "group1");
