@@ -70,6 +70,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.uberfire.backend.server.util.Paths;
 import org.uberfire.io.IOService;
+import org.uberfire.java.nio.EncodingUtil;
 import org.uberfire.java.nio.file.DirectoryStream;
 import org.uberfire.java.nio.file.Files;
 import org.uberfire.java.nio.file.Path;
@@ -316,8 +317,15 @@ public class Builder implements Serializable {
     }
 
     public IncrementalBuildResults addResource(final Path resource) {
-        return addResource(resource,
-                           ioService.newInputStream(resource));
+        IncrementalBuildResults results = new IncrementalBuildResults(projectGAV);
+        // This validation prevents faulty update resource operation that may come during save and rename operation
+        // For more information see https://github.com/kiegroup/kie-wb-common/pull/3277
+        if (ioService.exists(resource)) {
+            results = addResource(resource,
+                                  ioService.newInputStream(resource));
+        }
+
+        return results;
     }
 
     private IncrementalBuildResults addResource(final Path resource,
@@ -398,7 +406,7 @@ public class Builder implements Serializable {
     }
 
     private String destinationPath(final Path resource) {
-        final String destinationPath = resource.toUri().toString().substring(projectPrefix.length());
+        final String destinationPath = EncodingUtil.decode(resource.toUri().toString().substring(projectPrefix.length()));
 
         if (destinationPath.startsWith("/")) {
             // File in sub module
@@ -529,7 +537,7 @@ public class Builder implements Serializable {
     private void buildIncrementally(final IncrementalBuildResults results,
                                     final String... destinationPath) {
         try {
-            final IncrementalResults incrementalResults = ((InternalKieBuilder) kieBuilder).createFileSet(destinationPath).build();
+            final IncrementalResults incrementalResults = ((InternalKieBuilder) kieBuilder).createFileSet(Message.Level.WARNING, destinationPath).build();
             results.addAllAddedMessages(convertMessages(incrementalResults.getAddedMessages(),
                                                         handles));
             results.addAllRemovedMessages(convertMessages(incrementalResults.getRemovedMessages(),
