@@ -17,21 +17,25 @@
 package org.kie.workbench.common.stunner.client.widgets.explorer.tree;
 
 import java.util.List;
+import java.util.OptionalInt;
 import java.util.function.Predicate;
+import java.util.logging.Level;
+import java.util.logging.Logger;
 
-import javax.annotation.PostConstruct;
+import javax.annotation.PreDestroy;
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
 import javax.enterprise.event.Observes;
+import javax.enterprise.inject.Any;
 import javax.inject.Inject;
 
 import com.google.gwt.user.client.ui.IsWidget;
 import com.google.gwt.user.client.ui.Widget;
 import org.jboss.errai.common.client.api.IsElement;
 import org.jboss.errai.common.client.ui.ElementWrapperWidget;
+import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.kie.workbench.common.stunner.client.widgets.components.glyph.DOMGlyphRenderers;
 import org.kie.workbench.common.stunner.core.client.api.ShapeManager;
-import org.kie.workbench.common.stunner.core.client.canvas.Canvas;
 import org.kie.workbench.common.stunner.core.client.canvas.CanvasHandler;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.actions.TextPropertyProvider;
 import org.kie.workbench.common.stunner.core.client.canvas.controls.actions.TextPropertyProviderFactory;
@@ -55,11 +59,17 @@ import org.kie.workbench.common.stunner.core.graph.processing.traverse.content.C
 import org.kie.workbench.common.stunner.core.graph.util.GraphUtils;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
 import org.uberfire.client.mvp.UberView;
+import org.uberfire.mvp.Command;
+
+import static org.kie.workbench.common.stunner.core.graph.util.GraphUtils.getChildIndex;
+import static org.kie.workbench.common.stunner.core.graph.util.GraphUtils.getParent;
 
 @Dependent
 public class TreeExplorer implements IsWidget {
 
-    static final String NO_NAME = "- No name -";
+    private static final Logger LOGGER = Logger.getLogger(TreeExplorer.class.getName());
+
+    static final String NO_NAME = "-- No name --";
 
     private final int icoHeight = 16;
     private final int icoWidth = 16;
@@ -68,11 +78,13 @@ public class TreeExplorer implements IsWidget {
     private final DefinitionUtils definitionUtils;
     private final ShapeManager shapeManager;
     private final Event<CanvasSelectionEvent> selectionEvent;
-    private final View view;
+    private final ManagedInstance<View> views;
     private final DOMGlyphRenderers domGlyphRenderers;
 
     private String selectedItemCanvasUuid;
     private CanvasHandler canvasHandler;
+    private View view;
+    private boolean eventInProgress;
 
     @Inject
     public TreeExplorer(final ChildrenTraverseProcessor childrenTraverseProcessor,
@@ -81,32 +93,28 @@ public class TreeExplorer implements IsWidget {
                         final DefinitionUtils definitionUtils,
                         final ShapeManager shapeManager,
                         final DOMGlyphRenderers domGlyphRenderers,
-                        final View view) {
+                        final @Any ManagedInstance<View> views) {
         this.childrenTraverseProcessor = childrenTraverseProcessor;
         this.textPropertyProviderFactory = textPropertyProviderFactory;
         this.selectionEvent = selectionEvent;
         this.definitionUtils = definitionUtils;
         this.shapeManager = shapeManager;
         this.domGlyphRenderers = domGlyphRenderers;
-        this.view = view;
-    }
-
-    @PostConstruct
-    public void init() {
-        view.init(this);
+        this.views = views;
+        this.eventInProgress = false;
     }
 
     @SuppressWarnings("unchecked")
     public void show(final CanvasHandler canvasHandler) {
         this.canvasHandler = canvasHandler;
+        initView();
         if (null != canvasHandler && null != canvasHandler.getDiagram()) {
             doShow(canvasHandler.getDiagram().getGraph());
         }
     }
 
     private void doShow(final Graph<org.kie.workbench.common.stunner.core.graph.content.view.View, Node<org.kie.workbench.common.stunner.core.graph.content.view.View, Edge>> graph) {
-        traverseChildrenEdges(graph,
-                              true);
+        runWithErrorHandling(() -> traverseChildrenEdges(graph, true));
     }
 
     private void traverseChildrenEdges(final Graph<org.kie.workbench.common.stunner.core.graph.content.view.View, Node<org.kie.workbench.common.stunner.core.graph.content.view.View, Edge>> graph,
@@ -141,73 +149,32 @@ public class TreeExplorer implements IsWidget {
     private Glyph getGlyph(final String shapeSetId,
                            final Element<org.kie.workbench.common.stunner.core.graph.content.view.View> element) {
         final Object definition = element.getContent().getDefinition();
-        final String defId = definitionUtils.getDefinitionManager().adapters().forDefinition().getId(definition);
+        final String defId = definitionUtils.getDefinitionManager().adapters().forDefinition().getId(definition).value();
         final ShapeFactory factory = shapeManager.getShapeSet(shapeSetId).getShapeFactory();
         return factory.getGlyph(defId);
     }
 
-    private void inc(final List<Integer> levels,
-                     final int level) {
-        if (levels.size() < (level + 1)) {
-            levels.add(0);
-        } else {
-            final int idx = levels.get(level);
-            levels.set(level,
-                       idx + 1);
-        }
-    }
-
-    private int[] getParentsIdx(final List<Integer> idxList,
-                                final int maxLevel) {
-
-        if (!idxList.isEmpty()) {
-            final int targetPos = (idxList.size() - (idxList.size() - maxLevel)) + 1;
-            final int[] resultArray = new int[targetPos];
-            for (int x = 0; x < targetPos; x++) {
-                resultArray[x] = idxList.get(x);
-            }
-            return resultArray;
-        }
-        return new int[]{};
-    }
-
     public void clear() {
         view.clear();
     }
 
+    @PreDestroy
     public void destroy() {
-        this.selectedItemCanvasUuid = null;
-        view.destroy();
+        destroyView();
+        selectedItemCanvasUuid = null;
+        canvasHandler = null;
     }
 
     void onSelect(final String uuid) {
-        selectShape(canvasHandler.getCanvas(),
-                    uuid);
-    }
-
-    private void selectShape(final Canvas canvas,
-                             final String uuid) {
-        selectionEvent.fire(new CanvasSelectionEvent(canvasHandler,
-                                                     uuid));
-    }
-
-    void onCanvasClearEvent(@Observes CanvasClearEvent canvasClearEvent) {
-        if (null != canvasHandler &&
-                null != canvasHandler.getCanvas() &&
-                canvasHandler.getCanvas().equals(canvasClearEvent.getCanvas())) {
-            clear();
-        }
-    }
-
-    void onCanvasElementAddedEvent(final @Observes CanvasElementAddedEvent canvasElementAddedEvent) {
-        if (checkEventContext(canvasElementAddedEvent)) {
-            onElementAdded(canvasElementAddedEvent.getElement());
+        if (!eventInProgress) {
+            selectionEvent.fire(new CanvasSelectionEvent(canvasHandler,
+                                                         uuid));
         }
     }
 
     private void onElementAdded(Element element) {
         if (isValidTreeItem().test(element)) {
-            final Element parent = GraphUtils.getParent((Node<?, ? extends Edge>) element);
+            final Element parent = getParent((Node<?, ? extends Edge>) element);
             addItem(parent,
                     (Node) element,
                     true,
@@ -219,18 +186,19 @@ public class TreeExplorer implements IsWidget {
     private void onElementUpdated(Element element,
                                   CanvasHandler canvasHandler) {
         if (isValidTreeItem().test(element)) {
-            final Element lane = GraphUtils.getParent((Node<?, ? extends Edge>) element);
-
+            final Element parent = getParent((Node<?, ? extends Edge>) element);
+            final int childCount = null != element.asNode() ? GraphUtils.countChildren(element.asNode()).intValue() : 0;
+            final OptionalInt childIndex = getChildIndex(parent, element.getUUID());
             if (view.isItemChanged(element.getUUID(),
-                                   null != lane ? lane.getUUID() : null,
-                                   getItemName(element))) {
-
+                                   null != parent ? parent.getUUID() : null,
+                                   getItemName(element),
+                                   childCount,
+                                   childIndex)) {
                 view.removeItem(element.getUUID());
-                addItem(lane,
+                addItem(parent,
                         (Node) element,
                         true,
                         true);
-
                 final boolean hasChildren = GraphUtils.hasChildren((Node<?, ? extends Edge>) element);
                 if (hasChildren) {
                     childrenTraverseProcessor
@@ -258,6 +226,9 @@ public class TreeExplorer implements IsWidget {
                                                       false);
                                           }
                                       });
+                } else {
+                    // highlight the updated item which is not a parent
+                    view.setSelectedItem(element.getUUID());
                 }
             }
         }
@@ -290,7 +261,7 @@ public class TreeExplorer implements IsWidget {
             final boolean wasParentContainer = view.isContainer(parent.getUUID());
             if (isParentContainer != wasParentContainer) {
                 view.removeItem(parent.getUUID());
-                addItem(GraphUtils.getParent((Node<?, ? extends Edge>) parent),
+                addItem(getParent((Node<?, ? extends Edge>) parent),
                         (Node) parent,
                         expand,
                         false);
@@ -306,7 +277,8 @@ public class TreeExplorer implements IsWidget {
                          name,
                          widget,
                          isContainer,
-                         expand);
+                         expand,
+                         getChildIndex(parent, element.getUUID()));
         } else {
             view.addItem(element.getUUID(),
                          name,
@@ -341,48 +313,103 @@ public class TreeExplorer implements IsWidget {
                 checkParent);
     }
 
+    void onCanvasClearEvent(@Observes CanvasClearEvent canvasClearEvent) {
+        checkEventContext(canvasClearEvent,
+                          this::clear);
+    }
+
+    void onCanvasElementAddedEvent(final @Observes CanvasElementAddedEvent canvasElementAddedEvent) {
+        checkEventContext(canvasElementAddedEvent,
+                          () -> onElementAdded(canvasElementAddedEvent.getElement()));
+    }
+
     void onCanvasElementRemovedEvent(final @Observes CanvasElementRemovedEvent elementRemovedEvent) {
-        if (checkEventContext(elementRemovedEvent)) {
-            onElementRemoved(elementRemovedEvent.getElement());
-        }
+        checkEventContext(elementRemovedEvent,
+                          () -> onElementRemoved(elementRemovedEvent.getElement()));
     }
 
     void onCanvasElementsClearEvent(final @Observes CanvasElementsClearEvent canvasClearEvent) {
-        if (checkEventContext(canvasClearEvent)) {
-            showEventGraph(canvasClearEvent);
-        }
+        checkEventContext(canvasClearEvent,
+                          () -> showEventGraph(canvasClearEvent));
     }
 
     void onCanvasElementUpdatedEvent(final @Observes CanvasElementUpdatedEvent canvasElementUpdatedEvent) {
-        if (checkEventContext(canvasElementUpdatedEvent)) {
-            onElementUpdated(canvasElementUpdatedEvent.getElement(),
-                             canvasElementUpdatedEvent.getCanvasHandler());
-        }
+        checkEventContext(canvasElementUpdatedEvent,
+                          () -> onElementUpdated(canvasElementUpdatedEvent.getElement(),
+                                                 canvasElementUpdatedEvent.getCanvasHandler()));
     }
 
     void onCanvasSelectionEvent(final @Observes CanvasSelectionEvent event) {
-        if (checkEventContext(event)) {
-            if (null != getCanvasHandler()
-                    && event.getIdentifiers().size() == 1) {
-                final String uuid = event.getIdentifiers().iterator().next();
+        checkEventContext(event,
+                          () -> {
+                              if (null != getCanvasHandler()
+                                      && event.getIdentifiers().size() == 1) {
+                                  final String uuid = event.getIdentifiers().iterator().next();
+                                  select(uuid);
+                                  focusCanvasToActivateKeyboardCanvasControl();
+                              }
+                          });
+    }
 
-                if (!(uuid.equals(this.selectedItemCanvasUuid))) {
-                    this.selectedItemCanvasUuid = uuid;
-                    view.setSelectedItem(uuid);
-                }
-            }
+    private void focusCanvasToActivateKeyboardCanvasControl() {
+        if (getCanvasHandler().getCanvas() != null) {
+            getCanvasHandler().getCanvas().focus();
         }
     }
 
-    private boolean checkEventContext(final AbstractCanvasHandlerEvent canvasHandlerEvent) {
-        final CanvasHandler _canvasHandler = canvasHandlerEvent.getCanvasHandler();
-        return canvasHandler != null && canvasHandler.equals(_canvasHandler);
+    private boolean select(final String uuid) {
+        if (!(uuid.equals(this.selectedItemCanvasUuid))) {
+            this.selectedItemCanvasUuid = uuid;
+            view.setSelectedItem(uuid);
+            return true;
+        }
+        return false;
     }
 
-    private boolean checkEventContext(final AbstractCanvasEvent canvasEvent) {
-        final Canvas canvas = canvasEvent.getCanvas();
-        return null != canvasHandler && null != canvasHandler.getCanvas()
-                && canvasHandler.getCanvas().equals(canvas);
+    void checkEventContext(final AbstractCanvasEvent canvasEvent,
+                           final Command runnable) {
+        if (null != canvasHandler &&
+                null != canvasHandler.getCanvas() &&
+                canvasHandler.getCanvas().equals(canvasEvent.getCanvas())) {
+            runEventInContext(runnable);
+        }
+    }
+
+    private void checkEventContext(final AbstractCanvasHandlerEvent canvasHandlerEvent,
+                                   final Command runnable) {
+        final CanvasHandler _canvasHandler = canvasHandlerEvent.getCanvasHandler();
+        if (canvasHandler != null && canvasHandler.equals(_canvasHandler)) {
+            runEventInContext(runnable);
+        }
+    }
+
+    private void runEventInContext(final Command runnable) {
+        eventInProgress = true;
+        runWithErrorHandling(runnable::execute);
+        eventInProgress = false;
+    }
+
+    private void runWithErrorHandling(Runnable runnable) {
+        try {
+            runnable.run();
+        } catch (Exception ex) {
+            LOGGER.log(Level.SEVERE, "An error occurred while updating tree explorer.", ex);
+            view.clear();
+        }
+    }
+
+    private void initView() {
+        if (null != view) {
+            destroyView();
+        }
+        view = views.get();
+        view.init(this);
+    }
+
+    private void destroyView() {
+        view.destroy();
+        views.destroy(view);
+        view = null;
     }
 
     private String getShapeSetId() {
@@ -403,6 +430,10 @@ public class TreeExplorer implements IsWidget {
         return canvasHandler;
     }
 
+    boolean isEventInProgress() {
+        return eventInProgress;
+    }
+
     private String getItemName(final Element<org.kie.workbench.common.stunner.core.graph.content.view.View> item) {
         final TextPropertyProvider provider = textPropertyProviderFactory.getProvider(item);
         final String name = provider.getText(item);
@@ -416,20 +447,21 @@ public class TreeExplorer implements IsWidget {
 
     public interface View extends UberView<TreeExplorer> {
 
-        View addItem(final String uuid,
-                     final String name,
-                     final IsWidget icon,
-                     final boolean isContainer,
-                     final boolean state);
+        View addItem(String uuid,
+                     String name,
+                     IsWidget icon,
+                     boolean isContainer,
+                     boolean state);
 
-        View addItem(final String uuid,
-                     final String parentUuid,
-                     final String name,
-                     final IsWidget icon,
-                     final boolean isContainer,
-                     final boolean state);
+        View addItem(String uuid,
+                     String parentUuid,
+                     String name,
+                     IsWidget icon,
+                     boolean isContainer,
+                     boolean state,
+                     OptionalInt index);
 
-        View setSelectedItem(final String uuid);
+        View setSelectedItem(String uuid);
 
         View removeItem(String uuid);
 
@@ -437,10 +469,12 @@ public class TreeExplorer implements IsWidget {
 
         View destroy();
 
-        boolean isItemChanged(final String uuid,
-                              final String parentUuid,
-                              final String name);
+        boolean isItemChanged(String uuid,
+                              String parentUuid,
+                              String name,
+                              int childCount,
+                              OptionalInt indexIntoParent);
 
-        boolean isContainer(final String uuid);
+        boolean isContainer(String uuid);
     }
 }
