@@ -36,6 +36,11 @@ public final class Point2D {
                            y);
     }
 
+    public static Point2D clone(final Point2D point) {
+        return new Point2D(point.getX(),
+                           point.getY());
+    }
+
     public Point2D(final @MapsTo("x") double x,
                    final @MapsTo("y") double y) {
         this.x = x;
@@ -58,6 +63,10 @@ public final class Point2D {
         this.y = y;
     }
 
+    public Point2D copy() {
+        return new Point2D(x, y);
+    }
+
     @Override
     public boolean equals(Object o) {
         if (this == o) {
