@@ -16,22 +16,15 @@
 
 package org.kie.workbench.common.stunner.core.client.components.toolbox.actions;
 
-import java.util.function.Consumer;
-
-import org.kie.workbench.common.stunner.core.client.shape.view.event.MouseClickEvent;
-import org.kie.workbench.common.stunner.core.definition.shape.Glyph;
-
 public interface ActionsToolboxView<V extends ActionsToolboxView> {
 
-    public V init(ActionsToolbox toolbox);
+    V init(ActionsToolbox toolbox);
 
-    public V addButton(Glyph glyph,
-                       String title,
-                       Consumer<MouseClickEvent> clickEventConsumer);
+    V show();
 
-    public V show();
+    V hide();
 
-    public V hide();
+    void destroy();
 
-    public void destroy();
+    void hideAndDestroy();
 }
\ No newline at end of file
