@@ -29,15 +29,12 @@ import org.kie.workbench.common.stunner.core.definition.adapter.DefinitionAdapte
 import org.kie.workbench.common.stunner.core.definition.adapter.DefinitionId;
 import org.kie.workbench.common.stunner.core.definition.adapter.DefinitionSetRuleAdapter;
 import org.kie.workbench.common.stunner.core.definition.adapter.PropertyAdapter;
-import org.kie.workbench.common.stunner.core.factory.impl.EdgeFactoryImpl;
-import org.kie.workbench.common.stunner.core.factory.impl.GraphFactoryImpl;
-import org.kie.workbench.common.stunner.core.factory.impl.NodeFactoryImpl;
+import org.kie.workbench.common.stunner.core.definition.adapter.PropertySetAdapter;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Graph;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.command.ContextualGraphCommandExecutionContext;
 import org.kie.workbench.common.stunner.core.graph.command.GraphCommandExecutionContext;
-import org.kie.workbench.common.stunner.core.graph.command.impl.GraphCommandFactory;
 import org.kie.workbench.common.stunner.core.graph.content.Bounds;
 import org.kie.workbench.common.stunner.core.graph.content.definition.Definition;
 import org.kie.workbench.common.stunner.core.graph.content.definition.DefinitionSet;
@@ -47,13 +44,11 @@ import org.kie.workbench.common.stunner.core.registry.definition.AdapterRegistry
 import org.kie.workbench.common.stunner.core.registry.definition.TypeDefinitionSetRegistry;
 import org.kie.workbench.common.stunner.core.registry.impl.RuleHandlerRegistryImpl;
 import org.kie.workbench.common.stunner.core.registry.rule.RuleHandlerRegistry;
-import org.kie.workbench.common.stunner.core.rule.RuleEvaluationContext;
 import org.kie.workbench.common.stunner.core.rule.RuleManager;
 import org.kie.workbench.common.stunner.core.rule.RuleManagerImpl;
 import org.kie.workbench.common.stunner.core.rule.RuleSet;
 import org.kie.workbench.common.stunner.core.rule.RuleSetImpl;
 import org.kie.workbench.common.stunner.core.rule.RuleViolation;
-import org.kie.workbench.common.stunner.core.rule.RuleViolations;
 import org.kie.workbench.common.stunner.core.rule.handler.impl.CardinalityEvaluationHandler;
 import org.kie.workbench.common.stunner.core.rule.handler.impl.ConnectionEvaluationHandler;
 import org.kie.workbench.common.stunner.core.rule.handler.impl.ConnectorCardinalityEvaluationHandler;
@@ -64,15 +59,12 @@ import org.kie.workbench.common.stunner.core.rule.handler.impl.ElementCardinalit
 import org.kie.workbench.common.stunner.core.rule.handler.impl.GraphConnectionEvaluationHandler;
 import org.kie.workbench.common.stunner.core.rule.handler.impl.NodeContainmentEvaluationHandler;
 import org.kie.workbench.common.stunner.core.rule.handler.impl.NodeDockingEvaluationHandler;
-import org.kie.workbench.common.stunner.core.rule.violations.DefaultRuleViolations;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
-import org.mockito.Mock;
-import org.mockito.MockitoAnnotations;
 
 import static org.junit.Assert.assertNotEquals;
-import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.anyDouble;
+import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.when;
@@ -86,35 +78,9 @@ public class TestingGraphMockHandler {
 
     public static final String DEF_SET_ID = "defSetId";
     public static final String GRAPH_UUID = "graphUUID";
-    private final RuleViolations EMPTY_VIOLATIONS = new DefaultRuleViolations();
 
-    @Mock
-    public DefinitionManager definitionManager;
-    @Mock
-    public DefinitionUtils definitionUtils;
-    @Mock
-    public TypeDefinitionSetRegistry definitionSetRegistry;
-    @Mock
-    public AdapterManager adapterManager;
-    @Mock
-    public AdapterRegistry adapterRegistry;
-    @Mock
-    public DefinitionAdapter<Object> definitionAdapter;
-    @Mock
-    public PropertyAdapter propertyAdapter;
-    @Mock
-    public DefinitionSetRuleAdapter ruleAdapter;
-    @Mock
-    public FactoryManager factoryManager;
-    @Mock
-    public RuleManager ruleManager;
-    @Mock
+    public StunnerTestingGraphMockAPI graphAPI;
     public MutableIndex graphIndex;
-
-    public GraphFactoryImpl graphFactory;
-    public NodeFactoryImpl nodeFactory;
-    public EdgeFactoryImpl edgeFactory;
-    public GraphCommandFactory commandFactory;
     public Graph<DefinitionSet, Node> graph;
     public RuleSet ruleSet;
     public ContextualGraphCommandExecutionContext graphCommandExecutionContext;
@@ -124,39 +90,72 @@ public class TestingGraphMockHandler {
     }
 
     @SuppressWarnings("unchecked")
-    private TestingGraphMockHandler init() {
-        ruleSet = spy(new RuleSetImpl("TestingRuleSet", new ArrayList<>()));
-        MockitoAnnotations.initMocks(this);
-        this.graphFactory = new GraphFactoryImpl(definitionManager);
-        this.nodeFactory = new NodeFactoryImpl(definitionUtils);
-        this.edgeFactory = new EdgeFactoryImpl(definitionManager);
-        this.commandFactory = new GraphCommandFactory();
-        this.graph = graphFactory.build(GRAPH_UUID,
-                                        DEF_SET_ID);
-        when(definitionUtils.getDefinitionManager()).thenReturn(definitionManager);
-        when(definitionManager.definitionSets()).thenReturn(definitionSetRegistry);
-        when(definitionManager.adapters()).thenReturn(adapterManager);
-        when(adapterManager.registry()).thenReturn(adapterRegistry);
-        when(adapterManager.forDefinition()).thenReturn(definitionAdapter);
-        when(adapterManager.forProperty()).thenReturn(propertyAdapter);
-        when(adapterManager.forRules()).thenReturn(ruleAdapter);
-        when(adapterRegistry.getDefinitionAdapter(any(Class.class))).thenReturn(definitionAdapter);
-        when(adapterRegistry.getPropertyAdapter(any(Class.class))).thenReturn(propertyAdapter);
-        graphCommandExecutionContext = spy(new ContextualGraphCommandExecutionContext(definitionManager, factoryManager, ruleManager, graphIndex, ruleSet));
-        when(graphCommandExecutionContext.getRuleSet()).thenReturn(ruleSet);
+    private void init() {
+        this.graphAPI = new StunnerTestingGraphMockAPI();
+        this.graphIndex = mock(MutableIndex.class);
+        this.graph = spy(graphAPI.graphFactory.build(GRAPH_UUID, DEF_SET_ID));
+        this.ruleSet = spy(new RuleSetImpl("TestingRuleSet", new ArrayList<>()));
+        this.graphCommandExecutionContext = spy(new ContextualGraphCommandExecutionContext(getDefinitionManager(),
+                                                                                           getFactoryManager(),
+                                                                                           getRuleManager(),
+                                                                                           graphIndex,
+                                                                                           ruleSet));
+        //when(graphCommandExecutionContext.getRuleSet()).thenReturn(ruleSet);
         when(graphIndex.getGraph()).thenReturn(graph);
-        when(ruleManager.evaluate(any(RuleSet.class),
-                                  any(RuleEvaluationContext.class))).thenReturn(EMPTY_VIOLATIONS);
-        return this;
     }
 
+    public DefinitionManager getDefinitionManager() {
+        return graphAPI.getDefinitionManager();
+    }
+
+    public DefinitionUtils getDefinitionUtils() {
+        return graphAPI.getDefinitionUtils();
+    }
+
+    public TypeDefinitionSetRegistry getDefinitionSetRegistry() {
+        return graphAPI.getDefinitionSetRegistry();
+    }
+
+    public AdapterManager getAdapterManager() {
+        return graphAPI.getAdapterManager();
+    }
+
+    public AdapterRegistry getAdapterRegistry() {
+        return graphAPI.getAdapterRegistry();
+    }
+
+    public DefinitionAdapter getDefinitionAdapter() {
+        return graphAPI.getDefinitionAdapter();
+    }
+
+    public PropertyAdapter getPropertyAdapter() {
+        return graphAPI.getPropertyAdapter();
+    }
+
+    public PropertySetAdapter getPropertySetAdapter() {
+        return graphAPI.getPropertySetAdapter();
+    }
+
+    public DefinitionSetRuleAdapter getRuleAdapter() {
+        return graphAPI.getRuleAdapter();
+    }
+
+    public FactoryManager getFactoryManager() {
+        return graphAPI.getFactoryManager();
+    }
+
+    public RuleManager getRuleManager() {
+        return graphAPI.getRuleManager();
+    }
+
+    @SuppressWarnings("unchecked")
     public Object getDefIfPresent(final String id,
                                   final Optional<Object> actual) {
         Object definition = null;
         if (actual.isPresent()) {
             definition = actual.get();
-            if (null == definitionAdapter.getId(definition)) {
-                when(definitionAdapter.getId(eq(definition))).thenReturn(DefinitionId.build(id));
+            if (null == getDefinitionAdapter().getId(definition)) {
+                doReturn(DefinitionId.build(id)).when(getDefinitionAdapter()).getId(eq(definition));
             }
         } else {
             definition = newDef("def-" + id,
@@ -174,12 +173,13 @@ public class TestingGraphMockHandler {
         return def;
     }
 
+    @SuppressWarnings("unchecked")
     public void mockDefAttributes(final Object def,
                                   final String id,
                                   final Optional<Set<String>> labels) {
-        when(definitionAdapter.getId(eq(def))).thenReturn(DefinitionId.build(id));
+        doReturn(DefinitionId.build(id)).when(getDefinitionAdapter()).getId(eq(def));
         if (labels.isPresent()) {
-            when(definitionAdapter.getLabels(eq(def))).thenReturn(labels.get());
+            doReturn(labels.get()).when(getDefinitionAdapter()).getLabels(eq(def));
         }
     }
 
@@ -212,13 +212,13 @@ public class TestingGraphMockHandler {
                             final double w,
                             final double h) {
         final Object definition = getDefIfPresent(uuid, def);
-        when(definitionUtils.buildBounds(eq(definition),
-                                         anyDouble(),
-                                         anyDouble()))
-                .thenReturn(Bounds.create(x, y, x + w, y + h));
-        final Node<Definition<Object>, Edge> result = nodeFactory.build(uuid,
-                                                                        definition);
-        execute(commandFactory.addNode(result));
+        doReturn(Bounds.create(x, y, x + w, y + h))
+                .when(getDefinitionUtils()).buildBounds(eq(definition),
+                                                        anyDouble(),
+                                                        anyDouble());
+        final Node<Definition<Object>, Edge> result = graphAPI.nodeFactory.build(uuid,
+                                                                                 definition);
+        execute(graphAPI.commandFactory.addNode(result));
         when(graphIndex.getNode(eq(uuid))).thenReturn(result);
         when(graphIndex.get(eq(uuid))).thenReturn(result);
         return result;
@@ -233,7 +233,7 @@ public class TestingGraphMockHandler {
     }
 
     public Edge buildEdge(String uuid, Object definition) {
-        return edgeFactory.build(uuid, definition);
+        return graphAPI.edgeFactory.build(uuid, definition);
     }
 
     @SuppressWarnings("unchecked")
@@ -256,60 +256,60 @@ public class TestingGraphMockHandler {
     @SuppressWarnings("unchecked")
     public TestingGraphMockHandler setChild(final Node parent,
                                             final Node candidate) {
-        return execute(commandFactory.setChild(parent,
-                                               candidate));
+        return execute(graphAPI.commandFactory.setChild(parent,
+                                                        candidate));
     }
 
     @SuppressWarnings("unchecked")
     public TestingGraphMockHandler removeChild(final Node parent,
                                                final Node candidate) {
-        return execute(commandFactory.removeChild(parent,
-                                                  candidate));
+        return execute(graphAPI.commandFactory.removeChild(parent,
+                                                           candidate));
     }
 
     @SuppressWarnings("unchecked")
     public TestingGraphMockHandler dockTo(final Node parent,
                                           final Node candidate) {
-        return execute(commandFactory.dockNode(parent,
-                                               candidate));
+        return execute(graphAPI.commandFactory.dockNode(parent,
+                                                        candidate));
     }
 
     @SuppressWarnings("unchecked")
     public TestingGraphMockHandler addEdge(final Edge edge,
                                            final Node source) {
-        return execute(commandFactory.addConnector(source,
-                                                   edge,
-                                                   MagnetConnection.Builder.at(0d,
-                                                                               0d)));
+        return execute(graphAPI.commandFactory.addConnector(source,
+                                                            edge,
+                                                            MagnetConnection.Builder.at(0d,
+                                                                                        0d)));
     }
 
     @SuppressWarnings("unchecked")
     public TestingGraphMockHandler connectTo(final Edge edge,
                                              final Node target) {
-        return execute(commandFactory.setTargetNode(target,
-                                                    edge,
-                                                    MagnetConnection.Builder.at(0d,
-                                                                                0d)));
+        return execute(graphAPI.commandFactory.setTargetNode(target,
+                                                             edge,
+                                                             MagnetConnection.Builder.at(0d,
+                                                                                         0d)));
     }
 
     @SuppressWarnings("unchecked")
     public TestingGraphMockHandler removeTargetConnection(final Edge edge) {
-        return execute(commandFactory.setTargetNode(null,
-                                                    edge,
-                                                    MagnetConnection.Builder.at(0d,
-                                                                                0d)));
+        return execute(graphAPI.commandFactory.setTargetNode(null,
+                                                             edge,
+                                                             MagnetConnection.Builder.at(0d,
+                                                                                         0d)));
     }
 
     public RuleManager createRuleManagerImplementation() {
-        ElementCardinalityEvaluationHandler cardinalityEvaluationHandler = new ElementCardinalityEvaluationHandler(definitionManager,
+        ElementCardinalityEvaluationHandler cardinalityEvaluationHandler = new ElementCardinalityEvaluationHandler(getDefinitionManager(),
                                                                                                                    new CardinalityEvaluationHandler());
-        ConnectorCardinalityEvaluationHandler connectorCardinalityEvaluationHandler = new ConnectorCardinalityEvaluationHandler(definitionManager,
+        ConnectorCardinalityEvaluationHandler connectorCardinalityEvaluationHandler = new ConnectorCardinalityEvaluationHandler(getDefinitionManager(),
                                                                                                                                 new EdgeCardinalityEvaluationHandler());
-        GraphConnectionEvaluationHandler connectionEvaluationHandler = new GraphConnectionEvaluationHandler(definitionManager,
+        GraphConnectionEvaluationHandler connectionEvaluationHandler = new GraphConnectionEvaluationHandler(getDefinitionManager(),
                                                                                                             new ConnectionEvaluationHandler());
-        NodeContainmentEvaluationHandler containmentEvaluationHandler = new NodeContainmentEvaluationHandler(definitionManager,
+        NodeContainmentEvaluationHandler containmentEvaluationHandler = new NodeContainmentEvaluationHandler(getDefinitionManager(),
                                                                                                              new ContainmentEvaluationHandler());
-        NodeDockingEvaluationHandler dockingEvaluationHandler = new NodeDockingEvaluationHandler(definitionManager,
+        NodeDockingEvaluationHandler dockingEvaluationHandler = new NodeDockingEvaluationHandler(getDefinitionManager(),
                                                                                                  new DockingEvaluationHandler());
         RuleHandlerRegistry handlerRegistry = new RuleHandlerRegistryImpl();
         handlerRegistry.register(cardinalityEvaluationHandler);
