@@ -31,6 +31,7 @@ import bpsim.ScenarioParameters;
 import org.eclipse.bpmn2.ExtensionAttributeValue;
 import org.eclipse.bpmn2.LaneSet;
 import org.eclipse.bpmn2.Process;
+import org.eclipse.bpmn2.ProcessType;
 import org.eclipse.bpmn2.Property;
 import org.eclipse.bpmn2.Relationship;
 import org.eclipse.bpmn2.di.BPMNDiagram;
@@ -49,6 +50,7 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.cm.CaseFileVari
 import org.kie.workbench.common.stunner.bpmn.definition.property.cm.CaseIdPrefix;
 import org.kie.workbench.common.stunner.bpmn.definition.property.cm.CaseRoles;
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.GlobalVariables;
+import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.MetaDataAttributes;
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.imports.DefaultImport;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.SLADueDate;
 import org.kie.workbench.common.stunner.bpmn.definition.property.variables.BaseProcessVariables;
@@ -168,6 +170,10 @@ public class ProcessPropertyWriter extends BasePropertyWriter implements Element
         CustomAttribute.packageName.of(process).set(value);
     }
 
+    public void setType(String value) {
+        process.setProcessType(ProcessType.get(value));
+    }
+
     public void setVersion(String value) {
         CustomAttribute.version.of(process).set(value);
     }
@@ -187,15 +193,23 @@ public class ProcessPropertyWriter extends BasePropertyWriter implements Element
         List<Property> properties = process.getProperties();
         declarationList.getDeclarations().forEach(decl -> {
             VariableScope.Variable variable =
-                    variableScope.declare(this.process.getId(), decl.getIdentifier(), decl.getType(), decl.getKpi());
-            if (Boolean.parseBoolean(decl.getKpi())) {
-                CustomElement.customKPI.of(variable.getTypedIdentifier()).set(true);
+                    variableScope.declare(this.process.getId(), decl.getIdentifier(), decl.getType(), decl.getTags());
+
+            if (!decl.getTags().isEmpty()) {
+                CustomElement.customTags.of(variable.getTypedIdentifier()).set(decl.getTags());
             }
+
             properties.add(variable.getTypedIdentifier());
             this.itemDefinitions.add(variable.getTypeDeclaration());
         });
     }
 
+    public void setMetadata(final MetaDataAttributes metaDataAttributes) {
+        if (null != metaDataAttributes.getValue() && !metaDataAttributes.getValue().isEmpty()) {
+            CustomElement.metaDataAttributes.of(process).set(metaDataAttributes.getValue());
+        }
+    }
+
     public void setCaseFileVariables(CaseFileVariables caseFileVariables) {
         String value = caseFileVariables.getValue();
         DeclarationList declarationList = DeclarationList.fromString(value);
