@@ -28,21 +28,26 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Diagram
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Executable;
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.GlobalVariables;
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id;
+import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.MetaDataAttributes;
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Package;
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.ProcessInstanceDescription;
+import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.ProcessType;
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Version;
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.imports.Imports;
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.imports.ImportsValue;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.Documentation;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.Name;
 import org.kie.workbench.common.stunner.bpmn.definition.property.general.SLADueDate;
+import org.kie.workbench.common.stunner.bpmn.definition.property.variables.AdvancedData;
 import org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessData;
 import org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
 
-public class RootProcessConverter extends BaseRootProcessConverter<BPMNDiagramImpl, DiagramSet, ProcessData> {
+import static org.kie.workbench.common.stunner.core.util.StringUtils.revertIllegalCharsAttribute;
+
+public class RootProcessConverter extends BaseRootProcessConverter<BPMNDiagramImpl, DiagramSet, ProcessData, AdvancedData> {
 
     public RootProcessConverter(TypedFactoryManager typedFactoryManager,
                                 PropertyReaderFactory propertyReaderFactory,
@@ -58,14 +63,14 @@ public class RootProcessConverter extends BaseRootProcessConverter<BPMNDiagramIm
 
     @Override
     protected DiagramSet createDiagramSet(Process process, ProcessPropertyReader p, DefinitionsPropertyReader d) {
-        return new DiagramSet(new Name(process.getName()),
+        return new DiagramSet(new Name(revertIllegalCharsAttribute(process.getName())),
                               new Documentation(p.getDocumentation()),
-                              new Id(process.getId()),
+                              new Id(revertIllegalCharsAttribute(process.getId())),
                               new Package(p.getPackage()),
+                              new ProcessType(p.getProcessType()),
                               new Version(p.getVersion()),
                               new AdHoc(p.isAdHoc()),
                               new ProcessInstanceDescription(p.getDescription()),
-                              new GlobalVariables(p.getGlobalVariables()),
                               new Imports(new ImportsValue(p.getDefaultImports(), d.getWSDLImports())),
                               new Executable(process.isIsExecutable()),
                               new SLADueDate(p.getSlaDueDate()));
@@ -75,4 +80,9 @@ public class RootProcessConverter extends BaseRootProcessConverter<BPMNDiagramIm
     protected ProcessData createProcessData(String processVariables) {
         return new ProcessData(new ProcessVariables(processVariables));
     }
+
+    @Override
+    protected AdvancedData createAdvancedData(String globalVariables, String metaDataAttributes) {
+        return new AdvancedData(new GlobalVariables(globalVariables), new MetaDataAttributes(metaDataAttributes));
+    }
 }
