@@ -31,7 +31,7 @@ public interface StunnerFormsClientFieldsConstants extends Messages {
 
     String Cancel();
 
-    String Constant();
+    String Expression();
 
     String Custom();
 
@@ -57,7 +57,7 @@ public interface StunnerFormsClientFieldsConstants extends Messages {
 
     String Edit();
 
-    String Enter_constant();
+    String Enter_expression();
 
     String Enter_type();
 
@@ -65,7 +65,7 @@ public interface StunnerFormsClientFieldsConstants extends Messages {
 
     String Invalid_character_in_name();
 
-    String Max_assignees_added();
+    String Invalid_character_in_value();
 
     String Name();
 
@@ -75,16 +75,24 @@ public interface StunnerFormsClientFieldsConstants extends Messages {
 
     String Only_single_entry_allowed();
 
-    String Save();
+    String Only_expressions_allowed_for_output();
+
+    String Ok();
 
     String Source();
 
+    String assignment_source_help();
+
     String Target();
 
+    String assignment_target_help();
+
     String This_input_should_be_entered_as_a_property_for_the_task();
 
     String Removed_invalid_characters_from_name();
 
+    String Removed_invalid_characters_from_value();
+
     String A_Data_Input_with_this_name_already_exists();
 
     String ProcessModel();
@@ -92,4 +100,40 @@ public interface StunnerFormsClientFieldsConstants extends Messages {
     String ConfirmCloseBusinessProcessEditor();
 
     String DeleteDiagramVariableError();
+
+    String RenameDiagramVariableError();
+
+    String DuplicatedVariableNameError(String variableName);
+
+    String DuplicatedAttributeNameError(String attributeName);
+
+    String AssignmentNameAlreadyInUseAsMultipleInstanceInputOutputVariable(String assignmentName);
+
+    String Imports();
+
+    String No_Imports();
+
+    String No_Data_Type_Import();
+
+    String Data_Type_Import();
+
+    String Data_Type_Imports();
+
+    String Data_Type_Imports_Title();
+
+    String No_WSDL_Import();
+
+    String WSDL_Import();
+
+    String WSDL_Imports();
+
+    String WSDL_Imports_Title();
+
+    String Duplicate_Import(String location, String namespace);
+
+    String Location();
+
+    String Namespace();
+
+    String ClassName();
 }
