@@ -19,6 +19,7 @@ package org.kie.workbench.common.stunner.bpmn.client.forms.fields.variablesEdito
 import java.util.List;
 
 import com.google.gwt.user.client.ui.IsWidget;
+import org.gwtbootstrap3.client.ui.Button;
 import org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.VariableRow;
 import org.kie.workbench.common.stunner.bpmn.client.forms.util.ListBoxValues;
 import org.uberfire.backend.vfs.Path;
@@ -42,11 +43,19 @@ public interface VariablesEditorWidgetView extends IsWidget {
 
         boolean isDuplicateName(final String name);
 
+        boolean isBoundToNodes(final String name);
+
         void removeVariable(final VariableRow variableRow);
 
         ListBoxValues.ValueTester dataTypesTester();
 
         Path getDiagramPath();
+
+        void setLastOverlayOpened(final Button overlayCloseButton);
+
+        void closeLastOverlay();
+
+        Button getLastOverlayOpened();
     }
 
     void init(final Presenter presenter);
@@ -74,4 +83,6 @@ public interface VariablesEditorWidgetView extends IsWidget {
     void removeVariable(final VariableRow variableRow);
 
     void setReadOnly(final boolean readOnly);
+
+    void setTagsNotEnabled();
 }
